==> buildbot_2.10.1.orig.tar.gz: buildbot-2.10.1/master/buildbot/test/unit/steps/test_package_rpm_rpmlint.py <==
# This file is part of Buildbot.  Buildbot is free software: you can
# redistribute it and/or modify it under the terms of the GNU General Public
# License as published by the Free Software Foundation, version 2.
#
# This program is distributed in the hope that it will be useful, but WITHOUT
# ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS
# FOR A PARTICULAR PURPOSE.  See the GNU General Public License for more
# details.
#
# You should have received a copy of the GNU General Public License along with
# this program; if not, write to the Free Software Foundation, Inc., 51
# Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
#
# Copyright Buildbot Team Members

from twisted.trial import unittest

from buildbot.process.results import SUCCESS
from buildbot.steps.package.rpm import rpmlint
from buildbot.test.fake.remotecommand import ExpectShell
from buildbot.test.util import steps
from buildbot.test.util.misc import TestReactorMixin


class TestRpmLint(steps.BuildStepMixin, TestReactorMixin, unittest.TestCase):

    def setUp(self):
        self.setUpTestReactor()
        return self.setUpBuildStep()

    def tearDown(self):
        return self.tearDownBuildStep()

    def test_success(self):
        self.setupStep(rpmlint.RpmLint())
        self.expectCommands(
            ExpectShell(workdir='wkdir',
                        command=['rpmlint', '-i', '.'])
            + 0)
        self.expectOutcome(
            result=SUCCESS, state_string='Finished checking RPM/SPEC issues')
        return self.runStep()

    def test_fileloc_success(self):
        self.setupStep(rpmlint.RpmLint(fileloc='RESULT'))
        self.expectCommands(
            ExpectShell(workdir='wkdir',
                        command=['rpmlint', '-i', 'RESULT'])
            + 0)
        self.expectOutcome(result=SUCCESS)
        return self.runStep()

    def test_config_success(self):
        self.setupStep(rpmlint.RpmLint(config='foo.cfg'))
        self.expectCommands(
            ExpectShell(workdir='wkdir',
                        command=['rpmlint', '-i', '-f', 'foo.cfg', '.'])
            + 0)
        self.expectOutcome(result=SUCCESS)
        return self.runStep()

==> buildbot_3.10.1.orig.tar.gz: buildbot-3.10.1/master/buildbot/test/unit/steps/test_package_rpm_rpmlint.py <==
# This file is part of Buildbot.  Buildbot is free software: you can
# redistribute it and/or modify it under the terms of the GNU General Public
# License as published by the Free Software Foundation, version 2.
#
# This program is distributed in the hope that it will be useful, but WITHOUT
# ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS
# FOR A PARTICULAR PURPOSE.  See the GNU General Public License for more
# details.
#
# You should have received a copy of the GNU General Public License along with
# this program; if not, write to the Free Software Foundation, Inc., 51
# Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
#
# Copyright Buildbot Team Members

from twisted.trial import unittest

from buildbot.process.results import SUCCESS
from buildbot.steps.package.rpm import rpmlint
from buildbot.test.reactor import TestReactorMixin
from buildbot.test.steps import ExpectShell
from buildbot.test.steps import TestBuildStepMixin


class TestRpmLint(TestBuildStepMixin, TestReactorMixin, unittest.TestCase):

    def setUp(self):
        self.setup_test_reactor()
        return self.setup_test_build_step()

    def tearDown(self):
        return self.tear_down_test_build_step()

    def test_success(self):
        self.setup_step(rpmlint.RpmLint())
        self.expect_commands(
            ExpectShell(workdir='wkdir',
                        command=['rpmlint', '-i', '.'])
            .exit(0))
        self.expect_outcome(
            result=SUCCESS, state_string='Finished checking RPM/SPEC issues')
        return self.run_step()

    def test_fileloc_success(self):
        self.setup_step(rpmlint.RpmLint(fileloc='RESULT'))
        self.expect_commands(
            ExpectShell(workdir='wkdir',
                        command=['rpmlint', '-i', 'RESULT'])
            .exit(0))
        self.expect_outcome(result=SUCCESS)
        return self.run_step()

    def test_config_success(self):
        self.setup_step(rpmlint.RpmLint(config='foo.cfg'))
        self.expect_commands(
            ExpectShell(workdir='wkdir',
                        command=['rpmlint', '-i', '-f', 'foo.cfg', '.'])
            .exit(0))
        self.expect_outcome(result=SUCCESS)
        return self.run_step()
